package com.goldenwater.slaj.ttsa.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaExamEnte;

@Mapper
public interface BisTtsaExamEnteMapper {
    BisTtsaExamEnte selectBisTtsaExamEnteByGuid(String guid);
    List<BisTtsaExamEnte> selectBisTtsaExamEnteList(BisTtsaExamEnte bisTtsaExamEnte);
    int insertBisTtsaExamEnte(BisTtsaExamEnte bisTtsaExamEnte);
    int updateBisTtsaExamEnte(BisTtsaExamEnte bisTtsaExamEnte);
    int deleteBisTtsaExamEnteByGuid(String guid);
    int deleteBisTtsaExamEnteByGuids(String[] guids);
}
